@@ -15,13 +15,11 @@
 #include <core/form.h>
 #include <core/page.h>
 
-#include "../generators/poppler/config-okular-poppler.h"
-
 class FormatTest : public QObject
 {
     Q_OBJECT
 
-private slots:
+private Q_SLOTS:
     void initTestCase();
     void cleanupTestCase();
     void testTimeFormat();
@@ -61,7 +59,7 @@ void FormatTest::initTestCase()
     });
 
     const Okular::Page *page = m_document->page(0);
-    const QLinkedList<Okular::FormField *> pageFormFields = page->formFields();
+    const QList<Okular::FormField *> pageFormFields = page->formFields();
     for (Okular::FormField *ff : pageFormFields) {
         m_fields.insert(ff->name(), ff);
     }
