@@ -21,8 +21,6 @@
 #include <core/page.h>
 #include <core/script/event_p.h>
 
-#include "../generators/poppler/config-okular-poppler.h"
-
 class MessageBoxHelper : public QObject
 {
     Q_OBJECT
@@ -44,7 +42,7 @@ public:
         QVERIFY(m_clicked);
     }
 
-private slots:
+private Q_SLOTS:
     void closeMessageBox()
     {
         const QWidgetList allToplevelWidgets = QApplication::topLevelWidgets();
@@ -80,7 +78,7 @@ class KJSFunctionsTest : public QObject
 {
     Q_OBJECT
 
-private slots:
+private Q_SLOTS:
     void initTestCase();
     void testNthFieldName();
     void testDisplay();
@@ -108,7 +106,7 @@ void KJSFunctionsTest::initTestCase()
     QCOMPARE(m_document->openDocument(testFile, QUrl(), mime), Okular::Document::OpenSuccess);
 
     const Okular::Page *page = m_document->page(0);
-    const QLinkedList<Okular::FormField *> pageFormFields = page->formFields();
+    const QList<Okular::FormField *> pageFormFields = page->formFields();
     for (Okular::FormField *ff : pageFormFields) {
         m_fields.insert(ff->name(), ff);
     }
