@@ -115,6 +115,13 @@ void FormField::setAdditionalAction(Annotation::AdditionalActionType type, Actio
     d->m_additionalAnnotActions[type] = action;
 }
 
+QList<Action *> FormField::additionalActions() const
+{
+    Q_D(const FormField);
+    // yes, calling values() is not great but it's a list of ~10 elements, we can live with that
+    return d->m_additionalAnnotActions.values() + d->m_additionalActions.values(); // clazy:exclude=container-anti-pattern
+}
+
 Page *FormField::page() const
 {
     Q_D(const FormField);
@@ -240,11 +247,13 @@ public:
         for (const QString &str : choices) {
             bool ok = true;
             int val = str.toInt(&ok);
-            if (ok)
+            if (ok) {
                 newchoices.append(val);
+            }
         }
-        if (!newchoices.isEmpty())
+        if (!newchoices.isEmpty()) {
             q->setCurrentChoices(newchoices);
+        }
     }
 
     QString value() const override
