@@ -49,21 +49,24 @@ GeneratorPrivate::GeneratorPrivate()
 
 GeneratorPrivate::~GeneratorPrivate()
 {
-    if (mPixmapGenerationThread)
+    if (mPixmapGenerationThread) {
         mPixmapGenerationThread->wait();
+    }
 
     delete mPixmapGenerationThread;
 
-    if (mTextPageGenerationThread)
+    if (mTextPageGenerationThread) {
         mTextPageGenerationThread->wait();
+    }
 
     delete mTextPageGenerationThread;
 }
 
 PixmapGenerationThread *GeneratorPrivate::pixmapGenerationThread()
 {
-    if (mPixmapGenerationThread)
+    if (mPixmapGenerationThread) {
         return mPixmapGenerationThread;
+    }
 
     Q_Q(Generator);
     mPixmapGenerationThread = new PixmapGenerationThread(q);
@@ -75,8 +78,9 @@ PixmapGenerationThread *GeneratorPrivate::pixmapGenerationThread()
 
 TextPageGenerationThread *GeneratorPrivate::textPageGenerationThread()
 {
-    if (mTextPageGenerationThread)
+    if (mTextPageGenerationThread) {
         return mTextPageGenerationThread;
+    }
 
     Q_Q(Generator);
     mTextPageGenerationThread = new TextPageGenerationThread(q);
@@ -109,8 +113,9 @@ void GeneratorPrivate::pixmapGenerationFinished()
         request->page()->setPixmap(request->observer(), new QPixmap(QPixmap::fromImage(img)), request->normalizedRect());
         const int pageNumber = request->page()->number();
 
-        if (mPixmapGenerationThread->calcBoundingBox())
+        if (mPixmapGenerationThread->calcBoundingBox()) {
             q->updatePageBoundingBox(pageNumber, mPixmapGenerationThread->boundingBox());
+        }
     } else {
         // Cancel the text page generation too if it's still running
         if (mTextPageGenerationThread && mTextPageGenerationThread->isRunning()) {
@@ -303,8 +308,9 @@ void Generator::generatePixmap(PixmapRequest *request)
     d->mPixmapReady = true;
 
     signalPixmapRequestDone(request);
-    if (calcBoundingBox)
+    if (calcBoundingBox) {
         updatePageBoundingBox(pageNumber, Utils::imageBoundingBox(&img));
+    }
 }
 
 bool Generator::canGenerateTextPage() const
@@ -377,20 +383,19 @@ void Generator::pageSizeChanged(const PageSize &, const PageSize &)
 {
 }
 
-bool Generator::print(QPrinter &)
+Document::PrintError Generator::print(QPrinter &)
 {
-    return false;
-}
-
-Generator::PrintError Generator::printError() const
-{
-    return UnknownPrintError;
+    return Document::UnknownPrintError;
 }
 
 void Generator::opaqueAction(const BackendOpaqueAction * /*action*/)
 {
 }
 
+void Generator::freeOpaqueActionContents(const BackendOpaqueAction & /*action*/)
+{
+}
+
 QVariant Generator::metaData(const QString &key, const QVariant &option) const
 {
     Q_D(const Generator);
@@ -425,9 +430,9 @@ bool Generator::hasFeature(GeneratorFeature feature) const
 void Generator::signalPixmapRequestDone(PixmapRequest *request)
 {
     Q_D(Generator);
-    if (d->m_document)
+    if (d->m_document) {
         d->m_document->requestDone(request);
-    else {
+    } else {
         delete request;
     }
 }
@@ -435,16 +440,18 @@ void Generator::signalPixmapRequestDone(PixmapRequest *request)
 void Generator::signalTextGenerationDone(Page *page, TextPage *textPage)
 {
     Q_D(Generator);
-    if (d->m_document)
+    if (d->m_document) {
         d->m_document->textGenerationDone(page);
-    else
+    } else {
         delete textPage;
+    }
 }
 
 void Generator::signalPartialPixmapRequest(PixmapRequest *request, const QImage &image)
 {
-    if (request->shouldAbortRender())
+    if (request->shouldAbortRender()) {
         return;
+    }
 
     PagePrivate *pagePrivate = PagePrivate::get(request->page());
     pagePrivate->setPixmap(request->observer(), new QPixmap(QPixmap::fromImage(image)), request->normalizedRect(), true /* isPartialPixmap */);
@@ -465,35 +472,19 @@ const Document *Generator::document() const
 void Generator::setFeature(GeneratorFeature feature, bool on)
 {
     Q_D(Generator);
-    if (on)
+    if (on) {
         d->m_features.insert(feature);
-    else
+    } else {
         d->m_features.remove(feature);
-}
-
-QVariant Generator::documentMetaData(const QString &key, const QVariant &option) const
-{
-    Q_D(const Generator);
-    if (!d->m_document)
-        return QVariant();
-
-    if (key == QLatin1String("PaperColor"))
-        return documentMetaData(PaperColorMetaData, option);
-    if (key == QLatin1String("GraphicsAntialias"))
-        return documentMetaData(GraphicsAntialiasMetaData, option);
-    if (key == QLatin1String("TextAntialias"))
-        return documentMetaData(TextAntialiasMetaData, option);
-    if (key == QLatin1String("TextHinting"))
-        return documentMetaData(TextHintingMetaData, option);
-
-    return QVariant();
+    }
 }
 
 QVariant Generator::documentMetaData(const DocumentMetaDataKey key, const QVariant &option) const
 {
     Q_D(const Generator);
-    if (!d->m_document)
+    if (!d->m_document) {
         return QVariant();
+    }
 
     return d->m_document->documentMetaData(key, option);
 }
@@ -507,15 +498,17 @@ QMutex *Generator::userMutex() const
 void Generator::updatePageBoundingBox(int page, const NormalizedRect &boundingBox)
 {
     Q_D(Generator);
-    if (d->m_document) // still connected to document?
+    if (d->m_document) { // still connected to document?
         d->m_document->setPageBoundingBox(page, boundingBox);
+    }
 }
 
-void Generator::requestFontData(const Okular::FontInfo & /*font*/, QByteArray * /*data*/)
+QByteArray Generator::requestFontData(const Okular::FontInfo & /*font*/)
 {
+    return {};
 }
 
-void Generator::setDPI(const QSizeF &dpi) // clazy:exclude=function-args-by-value TODO remove the & when we do a BIC change elsewhere
+void Generator::setDPI(const QSizeF dpi)
 {
     Q_D(Generator);
     d->m_dpi = dpi;
@@ -644,8 +637,9 @@ bool PixmapRequest::isTile() const
 
 void PixmapRequest::setNormalizedRect(const NormalizedRect &rect)
 {
-    if (d->mNormalizedRect == rect)
+    if (d->mNormalizedRect == rect) {
         return;
+    }
 
     d->mNormalizedRect = rect;
 }
@@ -730,8 +724,9 @@ ExportFormat::ExportFormat(const ExportFormat &other)
 
 ExportFormat &ExportFormat::operator=(const ExportFormat &other)
 {
-    if (this == &other)
+    if (this == &other) {
         return *this;
+    }
 
     d = other.d;
 
