@@ -83,10 +83,11 @@ bool CHMGenerator::loadDocument(const QString &fileName, QVector<Okular::Page *>
             }
         }
         item.setAttribute(QStringLiteral("Icon"), e.iconid);
-        if (e.indent == 0)
+        if (e.indent == 0) {
             m_docSyn.appendChild(item);
-        else
+        } else {
             lastIndentElement[e.indent - 1].appendChild(item);
+        }
         lastIndentElement[e.indent] = item;
     }
 
@@ -94,23 +95,26 @@ bool CHMGenerator::loadDocument(const QString &fileName, QVector<Okular::Page *>
     QList<QUrl> pageList;
     m_file->enumerateFiles(pageList);
     const QUrl home = m_file->homeUrl();
-    if (home.path() != QLatin1String("/"))
+    if (home.path() != QLatin1String("/")) {
         pageList.prepend(home);
+    }
     m_pageUrl.resize(pageNum);
 
     for (const QUrl &qurl : qAsConst(pageList)) {
         QString url = qurl.toString();
         const QString urlLower = url.toLower();
-        if (!urlLower.endsWith(QLatin1String(".html")) && !urlLower.endsWith(QLatin1String(".htm")))
+        if (!urlLower.endsWith(QLatin1String(".html")) && !urlLower.endsWith(QLatin1String(".htm"))) {
             continue;
+        }
 
         int pos = url.indexOf(QLatin1Char(('#')));
         // insert the url into the maps, but insert always the variant without the #ref part
         QString tmpUrl = pos == -1 ? url : url.left(pos);
 
         // url already there, abort insertion
-        if (m_urlPage.contains(tmpUrl))
+        if (m_urlPage.contains(tmpUrl)) {
             continue;
+        }
 
         int foundPage = tmpPageList.value(tmpUrl, -1);
         if (foundPage != -1) {
@@ -179,8 +183,9 @@ void CHMGenerator::preparePageForSyncOperation(const QString &url)
 
 void CHMGenerator::slotCompleted()
 {
-    if (!m_request)
+    if (!m_request) {
         return;
+    }
 
     QImage image(m_request->width(), m_request->height(), QImage::Format_ARGB32);
     image.fill(Qt::white);
@@ -206,8 +211,9 @@ void CHMGenerator::slotCompleted()
     Okular::PixmapRequest *req = m_request;
     m_request = nullptr;
 
-    if (!req->page()->isBoundingBoxKnown())
+    if (!req->page()->isBoundingBoxKnown()) {
         updatePageBoundingBox(req->page()->number(), Okular::Utils::imageBoundingBox(&image));
+    }
     req->page()->setPixmap(req->observer(), new QPixmap(QPixmap::fromImage(image)));
     signalPixmapRequestDone(req);
 }
@@ -215,10 +221,12 @@ void CHMGenerator::slotCompleted()
 Okular::DocumentInfo CHMGenerator::generateDocumentInfo(const QSet<Okular::DocumentInfo::Key> &keys) const
 {
     Okular::DocumentInfo docInfo;
-    if (keys.contains(Okular::DocumentInfo::MimeType))
+    if (keys.contains(Okular::DocumentInfo::MimeType)) {
         docInfo.set(Okular::DocumentInfo::MimeType, QStringLiteral("application/x-chm"));
-    if (keys.contains(Okular::DocumentInfo::Title))
+    }
+    if (keys.contains(Okular::DocumentInfo::Title)) {
         docInfo.set(Okular::DocumentInfo::Title, m_file->title());
+    }
     return docInfo;
 }
 
@@ -250,7 +258,7 @@ void CHMGenerator::generatePixmap(Okular::PixmapRequest *request)
     m_chmUrl = url;
     m_syncGen->view()->resizeContents(requestWidth, requestHeight);
     m_request = request;
-    // will emit openURL without problems
+    // will Q_EMIT openURL without problems
     m_syncGen->openUrl(QUrl(pAddress));
 }
 
@@ -312,7 +320,7 @@ void CHMGenerator::recursiveExploreNodes(DOM::Node node, Okular::TextPage *tp)
             DOM::HTMLDocument domDoc = m_syncGen->htmlDocument();
             // only generate object info when generating a full page not a thumbnail
             if (genObjectRects) {
-                QLinkedList<Okular::ObjectRect *> objRects;
+                QList<Okular::ObjectRect *> objRects;
                 int xScale = m_syncGen->view()->width();
                 int yScale = m_syncGen->view()->height();
                 // getting links
@@ -327,9 +335,9 @@ void CHMGenerator::recursiveExploreNodes(DOM::Node node, Okular::TextPage *tp)
                             QString url = n.attributes().getNamedItem("href").nodeValue().string();
                             r = n.getRect();
                             // there is no way for us to support javascript properly
-                            if (url.startsWith(QLatin1String("JavaScript:")), Qt::CaseInsensitive)
+                            if (url.startsWith(QLatin1String("JavaScript:")), Qt::CaseInsensitive) {
                                 continue;
-                            else if (url.contains(QStringLiteral(":"))) {
+                            } else if (url.contains(QStringLiteral(":"))) {
                                 objRects.push_back(new Okular::ObjectRect(Okular::NormalizedRect(r, xScale, yScale), false, Okular::ObjectRect::Action, new Okular::BrowseAction(QUrl(url))));
                             } else {
                                 Okular::DocumentViewport viewport(metaData(QStringLiteral("NamedViewport"), absolutePath(m_chmUrl, url)).toString());
