@@ -57,13 +57,13 @@ Converter::~Converter()
 
 QTextDocument *Converter::convert(const QString &fileName)
 {
-    m_markdownFile = fopen(fileName.toLocal8Bit(), "rb");
+    m_markdownFile = fopen(fileName.toLocal8Bit().constData(), "rb");
     if (!m_markdownFile) {
-        emit error(i18n("Failed to open the document"), -1);
+        Q_EMIT error(i18n("Failed to open the document"), -1);
         return nullptr;
     }
 
-    m_fileDir = QDir(fileName.left(fileName.lastIndexOf('/')));
+    m_fileDir = QDir(fileName.left(fileName.lastIndexOf(QLatin1Char('/'))));
 
     QTextDocument *doc = convertOpenFile();
     QHash<QString, QTextFragment> internalLinks;
@@ -75,7 +75,7 @@ QTextDocument *Converter::convert(const QString &fileName)
         if (anchorIt != documentAnchors.constEnd()) {
             const Okular::DocumentViewport viewport = calculateViewport(doc, anchorIt.value());
             Okular::GotoAction *action = new Okular::GotoAction(QString(), viewport);
-            emit addAction(action, linkIt.value().position(), linkIt.value().position() + linkIt.value().length());
+            Q_EMIT addAction(action, linkIt.value().position(), linkIt.value().position() + linkIt.value().length());
         } else {
             qDebug() << "Could not find destination for" << linkIt.key();
         }
@@ -100,7 +100,7 @@ QTextDocument *Converter::convertOpenFile()
         flags |= MKD_NOPANTS;
     }
     if (!mkd_compile(markdownHandle, flags)) {
-        emit error(i18n("Failed to compile the Markdown document."), -1);
+        Q_EMIT error(i18n("Failed to compile the Markdown document."), -1);
         return nullptr;
     }
 
@@ -151,11 +151,11 @@ void Converter::extractLinks(const QTextBlock &parent, QHash<QString, QTextFragm
             const QTextCharFormat textCharFormat = textFragment.charFormat();
             if (textCharFormat.isAnchor()) {
                 const QString href = textCharFormat.anchorHref();
-                if (href.startsWith('#')) { // It's an internal link, store it and we'll resolve it at the end
+                if (href.startsWith(QLatin1Char('#'))) { // It's an internal link, store it and we'll resolve it at the end
                     internalLinks.insert(href.mid(1), textFragment);
                 } else {
                     Okular::BrowseAction *action = new Okular::BrowseAction(QUrl(textCharFormat.anchorHref()));
-                    emit addAction(action, textFragment.position(), textFragment.position() + textFragment.length());
+                    Q_EMIT addAction(action, textFragment.position(), textFragment.position() + textFragment.length());
                 }
 
                 const QStringList anchorNames = textCharFormat.anchorNames();
