@@ -12,9 +12,11 @@
 #define _OKULAR_GENERATOR_PDF_H_
 
 //#include "synctex/synctex_parser.h"
-#include <config-okular-poppler.h>
 
 #include <poppler-qt5.h>
+#include <poppler-version.h>
+
+#define POPPLER_VERSION_MACRO ((POPPLER_VERSION_MAJOR << 16) | (POPPLER_VERSION_MINOR << 8) | (POPPLER_VERSION_MICRO))
 
 #include <QBitArray>
 #include <QPointer>
@@ -108,7 +110,7 @@ public:
 
     QByteArray requestFontData(const Okular::FontInfo &font) override;
 
-#ifdef HAVE_POPPLER_SIGNING
+#if POPPLER_VERSION_MACRO >= QT_VERSION_CHECK(21, 1, 0)
     static void okularToPoppler(const Okular::NewSignatureData &oData, Poppler::PDFConverter::NewSignatureData *pData);
 #endif
 
@@ -127,7 +129,7 @@ private:
     // fetch the transition information and add it to the page
     void addTransition(Poppler::Page *pdfPage, Okular::Page *page);
     // fetch the poppler page form fields
-    QLinkedList<Okular::FormField *> getFormFields(Poppler::Page *popplerPage);
+    QList<Okular::FormField *> getFormFields(Poppler::Page *popplerPage);
 
     Okular::TextPage *abstractTextPage(const QList<Poppler::TextBox *> &text, double height, double width, int rot);
 
