@@ -48,7 +48,7 @@ QString PopplerCertificateInfo::subjectInfo(PopplerCertificateInfo::EntityInfoKe
 
 QString PopplerCertificateInfo::nickName() const
 {
-#ifdef HAVE_POPPLER_SIGNING
+#if POPPLER_VERSION_MACRO >= QT_VERSION_CHECK(21, 1, 0)
     return m_info.nickName();
 #else
     return i18n("Not Available");
@@ -69,22 +69,30 @@ PopplerCertificateInfo::KeyUsageExtensions PopplerCertificateInfo::keyUsageExten
 {
     Poppler::CertificateInfo::KeyUsageExtensions popplerKu = m_info.keyUsageExtensions();
     KeyUsageExtensions ku = KuNone;
-    if (popplerKu.testFlag(Poppler::CertificateInfo::KuDigitalSignature))
+    if (popplerKu.testFlag(Poppler::CertificateInfo::KuDigitalSignature)) {
         ku |= KuDigitalSignature;
-    if (popplerKu.testFlag(Poppler::CertificateInfo::KuNonRepudiation))
+    }
+    if (popplerKu.testFlag(Poppler::CertificateInfo::KuNonRepudiation)) {
         ku |= KuNonRepudiation;
-    if (popplerKu.testFlag(Poppler::CertificateInfo::KuKeyEncipherment))
+    }
+    if (popplerKu.testFlag(Poppler::CertificateInfo::KuKeyEncipherment)) {
         ku |= KuKeyEncipherment;
-    if (popplerKu.testFlag(Poppler::CertificateInfo::KuDataEncipherment))
+    }
+    if (popplerKu.testFlag(Poppler::CertificateInfo::KuDataEncipherment)) {
         ku |= KuDataEncipherment;
-    if (popplerKu.testFlag(Poppler::CertificateInfo::KuKeyAgreement))
+    }
+    if (popplerKu.testFlag(Poppler::CertificateInfo::KuKeyAgreement)) {
         ku |= KuKeyAgreement;
-    if (popplerKu.testFlag(Poppler::CertificateInfo::KuKeyCertSign))
+    }
+    if (popplerKu.testFlag(Poppler::CertificateInfo::KuKeyCertSign)) {
         ku |= KuKeyCertSign;
-    if (popplerKu.testFlag(Poppler::CertificateInfo::KuClrSign))
+    }
+    if (popplerKu.testFlag(Poppler::CertificateInfo::KuClrSign)) {
         ku |= KuClrSign;
-    if (popplerKu.testFlag(Poppler::CertificateInfo::KuEncipherOnly))
+    }
+    if (popplerKu.testFlag(Poppler::CertificateInfo::KuEncipherOnly)) {
         ku |= KuEncipherOnly;
+    }
     return ku;
 }
 
@@ -126,7 +134,7 @@ QByteArray PopplerCertificateInfo::certificateData() const
 
 bool PopplerCertificateInfo::checkPassword(const QString &password) const
 {
-#ifdef HAVE_POPPLER_SIGNING
+#if POPPLER_VERSION_MACRO >= QT_VERSION_CHECK(21, 1, 0)
     return m_info.checkPassword(password);
 #else
     Q_UNUSED(password);
@@ -256,7 +264,7 @@ const Okular::CertificateInfo &PopplerSignatureInfo::certificateInfo() const
     return *m_certfiticateInfo;
 }
 
-#ifdef HAVE_POPPLER_SIGNING
+#if POPPLER_VERSION_MACRO >= QT_VERSION_CHECK(21, 1, 0)
 PopplerCertificateStore::~PopplerCertificateStore() = default;
 
 QList<Okular::CertificateInfo *> PopplerCertificateStore::signingCertificates(bool *userCancelled) const
@@ -264,7 +272,7 @@ QList<Okular::CertificateInfo *> PopplerCertificateStore::signingCertificates(bo
     *userCancelled = false;
     auto PDFGeneratorNSSPasswordCallback = [&userCancelled](const char *element) -> char * {
         bool ok;
-        const QString pwd = QInputDialog::getText(nullptr, i18n("Enter Password"), i18n("Enter password to open %1:", element), QLineEdit::Password, QString(), &ok);
+        const QString pwd = QInputDialog::getText(nullptr, i18n("Enter Password"), i18n("Enter password to open %1:", QString::fromUtf8(element)), QLineEdit::Password, QString(), &ok);
         *userCancelled = !ok;
         return ok ? strdup(pwd.toUtf8().constData()) : nullptr;
     };
@@ -272,8 +280,9 @@ QList<Okular::CertificateInfo *> PopplerCertificateStore::signingCertificates(bo
 
     const QVector<Poppler::CertificateInfo> certs = Poppler::getAvailableSigningCertificates();
     QList<Okular::CertificateInfo *> vReturnCerts;
-    for (auto cert : certs)
+    for (const auto &cert : certs) {
         vReturnCerts.append(new PopplerCertificateInfo(cert));
+    }
 
     Poppler::setNSSPasswordCallback(nullptr);
 
