@@ -7,7 +7,6 @@
 #include "pagepainter.h"
 
 // qt / kde includes
-#include <KIconLoader>
 #include <QApplication>
 #include <QDebug>
 #include <QIcon>
@@ -33,7 +32,7 @@
 #include "settings.h"
 #include "settings_core.h"
 
-Q_GLOBAL_STATIC_WITH_ARGS(QPixmap, busyPixmap, (QIcon::fromTheme(QLatin1String("okular")).pixmap(KIconLoader::SizeLarge)))
+Q_GLOBAL_STATIC_WITH_ARGS(QPixmap, busyPixmap, (QIcon::fromTheme(QLatin1String("okular")).pixmap(48)))
 
 #define TEXTANNOTATION_ICONSIZE 24
 
@@ -155,12 +154,11 @@ void PagePainter::paintCroppedPageOnPainter(QPainter *destPainter,
                         {*/
 
             Okular::NormalizedRect *limitRect = new Okular::NormalizedRect(nXMin, nYMin, nXMax, nYMax);
-            QLinkedList<Okular::HighlightAreaRect *>::const_iterator h2It = page->m_highlights.constBegin(), hEnd = page->m_highlights.constEnd();
             Okular::HighlightAreaRect::const_iterator hIt;
-            for (; h2It != hEnd; ++h2It) {
-                for (hIt = (*h2It)->constBegin(); hIt != (*h2It)->constEnd(); ++hIt) {
+            for (const Okular::HighlightAreaRect *highlight : page->m_highlights) {
+                for (hIt = highlight->constBegin(); hIt != highlight->constEnd(); ++hIt) {
                     if ((*hIt).intersects(limitRect)) {
-                        bufferedHighlights->append(qMakePair((*h2It)->color, *hIt));
+                        bufferedHighlights->append(qMakePair(highlight->color, *hIt));
                     }
                 }
             }
@@ -186,9 +184,7 @@ void PagePainter::paintCroppedPageOnPainter(QPainter *destPainter,
         }
         // append annotations inside limits to the un/buffered list
         if (canDrawAnnotations) {
-            QLinkedList<Okular::Annotation *>::const_iterator aIt = page->m_annotations.constBegin(), aEnd = page->m_annotations.constEnd();
-            for (; aIt != aEnd; ++aIt) {
-                Okular::Annotation *ann = *aIt;
+            for (Okular::Annotation *ann : page->m_annotations) {
                 int flags = ann->flags();
 
                 if (flags & Okular::Annotation::Hidden) {
@@ -463,19 +459,14 @@ void PagePainter::paintCroppedPageOnPainter(QPainter *destPainter,
                     Okular::InkAnnotation *ia = (Okular::InkAnnotation *)a;
 
                     // draw each ink path
-                    const QList<QLinkedList<Okular::NormalizedPoint>> transformedInkPaths = ia->transformedInkPaths();
+                    const QList<QList<Okular::NormalizedPoint>> transformedInkPaths = ia->transformedInkPaths();
 
                     const QPen inkPen = buildPen(a, a->style().width(), acolor);
 
-                    int paths = transformedInkPaths.size();
-                    for (int p = 0; p < paths; p++) {
-                        NormalizedPath path;
-                        const QLinkedList<Okular::NormalizedPoint> &inkPath = transformedInkPaths[p];
-
+                    for (const QList<Okular::NormalizedPoint> &inkPath : transformedInkPaths) {
                         // normalize page point to image
-                        QLinkedList<Okular::NormalizedPoint>::const_iterator pIt = inkPath.constBegin(), pEnd = inkPath.constEnd();
-                        for (; pIt != pEnd; ++pIt) {
-                            const Okular::NormalizedPoint &inkPoint = *pIt;
+                        NormalizedPath path;
+                        for (const Okular::NormalizedPoint &inkPoint : inkPath) {
                             Okular::NormalizedPoint point;
                             point.x = (inkPoint.x - xOffset) * xScale;
                             point.y = (inkPoint.y - yOffset) * yScale;
@@ -679,9 +670,7 @@ void PagePainter::paintCroppedPageOnPainter(QPainter *destPainter,
         QRect limitsEnlarged = limits;
         limitsEnlarged.adjust(-2, -2, 2, 2);
         // draw rects that are inside the 'limits' paint region as opaque rects
-        QLinkedList<Okular::ObjectRect *>::const_iterator lIt = page->m_rects.constBegin(), lEnd = page->m_rects.constEnd();
-        for (; lIt != lEnd; ++lIt) {
-            Okular::ObjectRect *rect = *lIt;
+        for (Okular::ObjectRect *rect : page->m_rects) {
             if ((enhanceLinks && rect->objectType() == Okular::ObjectRect::Action) || (enhanceImages && rect->objectType() == Okular::ObjectRect::Image)) {
                 if (limitsEnlarged.intersects(rect->boundingRect(scaledWidth, scaledHeight).translated(-scaledCrop.topLeft()))) {
                     mixedPainter->strokePath(rect->region(), QPen(normalColor, 0));
@@ -1060,7 +1049,7 @@ LineAnnotPainter::LineAnnotPainter(const Okular::LineAnnotation *a, QSizeF pageS
 
 void LineAnnotPainter::draw(QImage &image) const
 {
-    const QLinkedList<Okular::NormalizedPoint> transformedLinePoints = la->transformedLinePoints();
+    const QList<Okular::NormalizedPoint> transformedLinePoints = la->transformedLinePoints();
     if (transformedLinePoints.count() == 2) {
         const Okular::NormalizedPoint delta {transformedLinePoints.last().x - transformedLinePoints.first().x, transformedLinePoints.first().y - transformedLinePoints.last().y};
         const double angle {atan2(delta.y * aspectRatio, delta.x)};
