@@ -148,7 +148,7 @@ void PixmapPreviewSelector::iconComboChanged(const QString &icon)
     }
     m_iconLabel->setPixmap(pixmap);
 
-    emit iconChanged(m_icon);
+    Q_EMIT iconChanged(m_icon);
 }
 
 void PixmapPreviewSelector::selectCustomStamp()
@@ -157,7 +157,7 @@ void PixmapPreviewSelector::selectCustomStamp()
     if (!customStampFile.isEmpty()) {
         QPixmap pixmap = Okular::AnnotationUtils::loadStamp(customStampFile, m_previewSize);
         if (pixmap.isNull()) {
-            KMessageBox::sorry(this, xi18nc("@info", "Could not load the file <filename>%1</filename>", customStampFile), i18nc("@title:window", "Invalid file"));
+            KMessageBox::error(this, xi18nc("@info", "Could not load the file <filename>%1</filename>", customStampFile), i18nc("@title:window", "Invalid file"));
         } else {
             m_comboItems->setEditText(customStampFile);
         }
@@ -469,8 +469,7 @@ void StampAnnotationWidget::createStyleWidget(QFormLayout *formlayout)
     formlayout->addRow(i18n("Stamp symbol:"), m_pixmapSelector);
     m_pixmapSelector->setEditable(true);
 
-    QPair<QString, QString> pair;
-    foreach (pair, defaultStamps()) {
+    for (const QPair<QString, QString> &pair : defaultStamps()) {
         m_pixmapSelector->addItem(pair.first, pair.second);
     }
 
